==> ssp-center-api-1.1.93-20231218.100336-3-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/OperatorMediaReportDataDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
*
*/
public class OperatorMediaReportDataDto implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
    * 主键
    */
    private Long id;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;

    /**
    * 安装数据
    */
    private Integer install;

    /**
    * 启动数据
    */
    private Integer start;

    /**
    * 注册数据
    */
    private Integer register;

    /**
    * 激活数据
    */
    private Integer activate;

    /**
    * 登录数据
    */
    private Integer login;

    /**
    * 付费数据
    */
    private Integer pay;

    /**
    * 进件数据
    */
    private Integer apply;

    /**
    * 完件数据
    */
    private Integer finish;

    /**
    * 签收数据
    */
    private Integer sign;

    /**
    * 拒签数据
    */
    private Integer reject;

    /**
    * 出单数据
    */
    private Integer export;

    /**
    * 拓展字段1
    */
    private Integer ext1;

    /**
    * 拓展字段2
    */
    private Integer ext2;

    /**
    * 上报策略ID  tb_operator_media_report_data
    */
    private Long strategyId;

    /**
    * 上报配置ID  tb_operator_media_report_config
    */
    private Long configId;

    /**
    * 上报日期
    */
    private Date statisticsTime;

    /**
    * 落地页转化数据
    */
    private Integer conversion;

    /**
     * 积木id
     */
    private String pageId;

    public String getPageId() {
        return pageId;
    }

    public void setPageId(String pageId) {
        this.pageId = pageId;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setInstall(Integer install) {
        this.install = install;
    }

    public Integer getInstall() {
        return install;
    }

    public void setStart(Integer start) {
        this.start = start;
    }

    public Integer getStart() {
        return start;
    }

    public void setRegister(Integer register) {
        this.register = register;
    }

    public Integer getRegister() {
        return register;
    }

    public void setActivate(Integer activate) {
        this.activate = activate;
    }

    public Integer getActivate() {
        return activate;
    }

    public void setLogin(Integer login) {
        this.login = login;
    }

    public Integer getLogin() {
        return login;
    }

    public void setPay(Integer pay) {
        this.pay = pay;
    }

    public Integer getPay() {
        return pay;
    }

    public void setApply(Integer apply) {
        this.apply = apply;
    }

    public Integer getApply() {
        return apply;
    }

    public void setFinish(Integer finish) {
        this.finish = finish;
    }

    public Integer getFinish() {
        return finish;
    }

    public void setSign(Integer sign) {
        this.sign = sign;
    }

    public Integer getSign() {
        return sign;
    }

    public void setReject(Integer reject) {
        this.reject = reject;
    }

    public Integer getReject() {
        return reject;
    }

    public void setExport(Integer export) {
        this.export = export;
    }

    public Integer getExport() {
        return export;
    }

    public void setExt1(Integer ext1) {
        this.ext1 = ext1;
    }

    public Integer getExt1() {
        return ext1;
    }

    public void setExt2(Integer ext2) {
        this.ext2 = ext2;
    }

    public Integer getExt2() {
        return ext2;
    }

    public void setStrategyId(Long strategyId) {
        this.strategyId = strategyId;
    }

    public Long getStrategyId() {
        return strategyId;
    }

    public void setConfigId(Long configId) {
        this.configId = configId;
    }

    public Long getConfigId() {
        return configId;
    }

    public void setStatisticsTime(Date statisticsTime) {
        this.statisticsTime = statisticsTime;
    }

    public Date getStatisticsTime() {
        return statisticsTime;
    }

    public void setConversion(Integer conversion) {
        this.conversion = conversion;
    }

    public Integer getConversion() {
        return conversion;
    }

}

==> ssp-center-api-1.2.46-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/OperatorMediaReportDataDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
*
*/
public class OperatorMediaReportDataDto implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
    * 主键
    */
    private Long id;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;

    /**
    * 安装数据
    */
    private Integer install;

    /**
    * 启动数据
    */
    private Integer start;

    /**
    * 注册数据
    */
    private Integer register;

    /**
    * 激活数据
    */
    private Integer activate;

    /**
    * 登录数据
    */
    private Integer login;

    /**
    * 付费数据
    */
    private Integer pay;

    /**
    * 进件数据
    */
    private Integer apply;

    /**
    * 完件数据
    */
    private Integer finish;

    /**
    * 签收数据
    */
    private Integer sign;

    /**
    * 拒签数据
    */
    private Integer reject;

    /**
    * 出单数据
    */
    private Integer export;

    /**
    * 拓展字段1
    */
    private Integer ext1;

    /**
    * 拓展字段2
    */
    private Integer ext2;

    /**
    * 上报策略ID  tb_operator_media_report_data
    */
    private Long strategyId;

    /**
    * 上报配置ID  tb_operator_media_report_config
    */
    private Long configId;

    /**
    * 上报日期
    */
    private Date statisticsTime;

    /**
    * 落地页转化数据
    */
    private Integer conversion;

    /**
     * 积木id
     */
    private String pageId;

    /**
     * 曝光 对应209日志
     */
    private Integer exposure;
    /**
     * 落地页转化 对应210日志
     */
    private Integer landPageConversion;

    public Integer getExposure() {
        return exposure;
    }

    public void setExposure(Integer exposure) {
        this.exposure = exposure;
    }

    public Integer getLandPageConversion() {
        return landPageConversion;
    }

    public void setLandPageConversion(Integer landPageConversion) {
        this.landPageConversion = landPageConversion;
    }

    public String getPageId() {
        return pageId;
    }

    public void setPageId(String pageId) {
        this.pageId = pageId;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setInstall(Integer install) {
        this.install = install;
    }

    public Integer getInstall() {
        return install;
    }

    public void setStart(Integer start) {
        this.start = start;
    }

    public Integer getStart() {
        return start;
    }

    public void setRegister(Integer register) {
        this.register = register;
    }

    public Integer getRegister() {
        return register;
    }

    public void setActivate(Integer activate) {
        this.activate = activate;
    }

    public Integer getActivate() {
        return activate;
    }

    public void setLogin(Integer login) {
        this.login = login;
    }

    public Integer getLogin() {
        return login;
    }

    public void setPay(Integer pay) {
        this.pay = pay;
    }

    public Integer getPay() {
        return pay;
    }

    public void setApply(Integer apply) {
        this.apply = apply;
    }

    public Integer getApply() {
        return apply;
    }

    public void setFinish(Integer finish) {
        this.finish = finish;
    }

    public Integer getFinish() {
        return finish;
    }

    public void setSign(Integer sign) {
        this.sign = sign;
    }

    public Integer getSign() {
        return sign;
    }

    public void setReject(Integer reject) {
        this.reject = reject;
    }

    public Integer getReject() {
        return reject;
    }

    public void setExport(Integer export) {
        this.export = export;
    }

    public Integer getExport() {
        return export;
    }

    public void setExt1(Integer ext1) {
        this.ext1 = ext1;
    }

    public Integer getExt1() {
        return ext1;
    }

    public void setExt2(Integer ext2) {
        this.ext2 = ext2;
    }

    public Integer getExt2() {
        return ext2;
    }

    public void setStrategyId(Long strategyId) {
        this.strategyId = strategyId;
    }

    public Long getStrategyId() {
        return strategyId;
    }

    public void setConfigId(Long configId) {
        this.configId = configId;
    }

    public Long getConfigId() {
        return configId;
    }

    public void setStatisticsTime(Date statisticsTime) {
        this.statisticsTime = statisticsTime;
    }

    public Date getStatisticsTime() {
        return statisticsTime;
    }

    public void setConversion(Integer conversion) {
        this.conversion = conversion;
    }

    public Integer getConversion() {
        return conversion;
    }

}
